@@ -250,7 +250,7 @@ class DaoAsync:
     async def usr_search(self,
                          site_id: int,
                          usr_id: str,
-                         role_list: str,
+                         role_list: list,
                          name_first: str,
                          name_last: str,
                          email: str,
@@ -270,13 +270,13 @@ class DaoAsync:
             qry.irec.criteria += query_builder.dyn_crit(usr_id,   'u', 'id', always_like=True)
 
         if role_list:
-            qry.irec.criteria += query_builder.dyn_list(role_list,  'u', 'roleid')
+            qry.irec.criteria += query_builder.dyn_list(role_list,  'u', 'role_id')
 
         if name_first:
-            qry.irec.criteria += query_builder.dyn_crit(name_first,  'u', 'namefirst', always_like=True)
+            qry.irec.criteria += query_builder.dyn_crit(name_first,  'u', 'name_first', always_like=True)
 
         if name_last:
-            qry.irec.criteria += query_builder.dyn_crit(name_last,  'u', 'namelast', always_like=True)
+            qry.irec.criteria += query_builder.dyn_crit(name_last,  'u', 'name_last', always_like=True)
 
         if email:
             qry.irec.criteria += query_builder.dyn_crit(email,  'u', 'email1', always_like=True)
@@ -288,7 +288,7 @@ class DaoAsync:
             qry.irec.criteria += query_builder.dyn_crit(title,  'u', 'title', always_like=True)
 
         if usr_type:
-            qry.irec.criteria += query_builder.dyn_crit(usr_type,  'u', 'usrtypeid')
+            qry.irec.criteria += query_builder.dyn_crit(usr_type,  'u', 'usrtype_id')
 
         if status_list:
             qry.irec.criteria += query_builder.dyn_list(status_list,  'u', 'status')
