@@ -166,7 +166,7 @@ class FuraServerImplAsync(FuraAsyncServerInterface):
         return usr_id
 
 
-    def _role(self):
+    async def _role(self):
         if not self._tok_data:
             raise Exception('Auth user required for RPC call, but no user is logged in!')
 
@@ -175,7 +175,7 @@ class FuraServerImplAsync(FuraAsyncServerInterface):
         if not role:
             raise Exception('Auth role is not set!')
 
-        return role
+        return await self._dao.role_get(self._site_id(), role)
 
 
     async def get_fura_token(self):
@@ -816,11 +816,11 @@ class FuraServerImplAsync(FuraAsyncServerInterface):
 
 
     async def user_role(self) -> tRole:
-        return self._role()
+        return await self._role()
 
 
     async def user_is_super_user(self) -> bool:
-        return self._role().status == tRole.Status_Couplet.key_super_user
+        return (await self._role()).status == tRole.Status_Couplet.key_super_user
 
 
     async def user_auth_change(self,
