@@ -751,7 +751,7 @@ Please contact your system administrator.')
                 ec == ErrCode.AuthOTPTarget    or\
                 ec == ErrCode.AuthOTPTMaxFails or\
                 ec == ErrCode.AuthOTPTMethod:
-            st = tUla.State_Couplet.key_otp_invalid
+            st = tUla.State_Couplet.key_o_t_p_invalid
         else:
             st = tUla.State_Couplet.key_unexpected_error
 
